@@ -34,205 +34,6 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         m <- transf(xd, type = "tolist", labels = lbs, prsep = prsep, 
             lb2lb = lb2lb)
     }
-    DF <- data.frame(matrix(ncol = 2L, nrow = length(m)))
-    DF[, 1] <- dhc(m, prsep = prsep)[which(1:(length(m) * 2L)%%2L == 
-        1L)]
-    DF[, 2] <- dhc(m, prsep = prsep)[which(1:(length(m) * 2L)%%2L == 
-        0L)]
-    DF <- DF[which(DF[, 1] != DF[, 2]), ]
-    out <- list()
-    inn <- list()
-    All <- list()
-    for (i in seq(lbs)) {
-        out[[i]] <- as.numeric(DF[which(DF[, 1] == as.numeric(lbs[i])), 
-            2])
-        inn[[i]] <- as.numeric(DF[which(DF[, 2] == as.numeric(lbs[i])), 
-            1])
-        All[[i]] <- c(out[[i]], inn[[i]])
-    }
-    rm(i)
-    finn <- list()
-    fout <- list()
-    for (i in seq(lbs)) {
-        finn[[i]] <- which(tabulate(inn[[i]]) == dim(x)[3])
-        fout[[i]] <- which(tabulate(out[[i]]) == dim(x)[3])
-    }
-    rm(i)
-    full <- list()
-    for (i in seq(lbs)) {
-        full[[i]] <- intersect(fout[[i]], finn[[i]])
-    }
-    rm(i)
-    rm(finn, fout)
-    asym <- list()
-    for (i in seq(lbs)) {
-        asym[[i]] <- which(tabulate(All[[i]]) == 1L)
-    }
-    rm(i)
-    sout <- list()
-    sinn <- list()
-    for (i in seq(lbs)) {
-        sout[[i]] <- which(tabulate(out[[i]]) == 1L)[which(!(which(tabulate(out[[i]]) == 
-            1L) %in% asym[[i]]))]
-        sinn[[i]] <- which(tabulate(inn[[i]]) == 1L)[which(!(which(tabulate(inn[[i]]) == 
-            1L) %in% asym[[i]]))]
-    }
-    rm(i)
-    dobl <- list()
-    dout <- list()
-    dinn <- list()
-    for (i in seq(lbs)) {
-        dobl[[i]] <- which(tabulate(All[[i]]) == 2L)
-        dout[[i]] <- which(tabulate(out[[i]]) == 2L)
-        dinn[[i]] <- which(tabulate(inn[[i]]) == 2L)
-    }
-    rm(i)
-    if ((is.na(dim(x)[3]) == FALSE | isTRUE(dim(x)[3] == 1) == 
-        TRUE)) {
-        Eout <- list()
-        length(Eout) <- length(lbs)
-        Einn <- list()
-        length(Einn) <- length(lbs)
-        TEnt <- list()
-        length(TEnt) <- length(lbs)
-        for (i in 1:length(dobl)) {
-            tmpout <- vector()
-            tmpinn <- vector()
-            for (j in 1:length(dobl[[i]])) {
-                if (isTRUE(dobl[[i]][j] %in% dout[[i]]) == TRUE) 
-                  tmpout[length(tmpout) + 1L] <- dobl[[i]][j]
-                if (isTRUE(dobl[[i]][j] %in% dinn[[i]]) == TRUE) 
-                  tmpinn[length(tmpinn) + 1L] <- dobl[[i]][j]
-            }
-            rm(j)
-            Eout[[i]] <- tmpout
-            Einn[[i]] <- tmpinn
-            TEnt[[i]] <- c(tmpout, tmpinn)
-        }
-        rm(tmpout, tmpinn)
-    }
-    else {
-        TEnt <- Eout <- Einn <- character(0)
-    }
-    trip <- list()
-    trin <- list()
-    trou <- list()
-    for (i in seq(lbs)) {
-        trip[[i]] <- which(tabulate(All[[i]]) > 2L)
-        trin[[i]] <- which(tabulate(inn[[i]]) > 2L)
-        trou[[i]] <- which(tabulate(out[[i]]) > 2L)
-    }
-    rm(i)
-    tripfl <- list()
-    trinfl <- list()
-    troufl <- list()
-    for (i in seq(lbs)) {
-        tripfl[[i]] <- trip[[i]][which(!(trip[[i]] %in% full[[i]]))]
-        trinfl[[i]] <- trin[[i]][which(!(trin[[i]] %in% full[[i]]))]
-        troufl[[i]] <- trou[[i]][which(!(trou[[i]] %in% full[[i]]))]
-    }
-    rm(i)
-    sngl <- list()
-    for (i in seq(lbs)) {
-        sngl[[i]] <- sout[[i]][which(!(sout[[i]] %in% tripfl[[i]]))]
-    }
-    rm(i)
-    recp <- list()
-    for (i in seq(lbs)) {
-        tmprcp <- vector()
-        for (j in 1:length(sngl[[i]])) {
-            chk <- paste(sngl[[i]][j], i, sep = prsep)
-            if (isTRUE(TRD == TRUE) == TRUE) {
-                for (k in 1:dim(x)[3]) {
-                  ifelse(isTRUE(all(c(chk, swp(chk, prsep = prsep)) %in% 
-                    mlt[[k]])) == TRUE, tmprcp <- append(tmprcp, 
-                    sngl[[i]][j]), NA)
-                }
-                rm(k)
-            }
-            else {
-                ifelse(isTRUE(all(c(chk, swp(chk, prsep = prsep)) %in% 
-                  m)) == TRUE, tmprcp <- append(tmprcp, sngl[[i]][j]), 
-                  NA)
-            }
-        }
-        rm(j)
-        recp[[i]] <- tmprcp
-    }
-    rm(i)
-    rm(tmprcp)
-    if (isTRUE(TRD == TRUE) == TRUE) {
-        xchg <- list()
-        for (i in seq(lbs)) {
-            xchg[[i]] <- sngl[[i]][which(!(sngl[[i]] %in% recp[[i]]))]
-        }
-        rm(i)
-    }
-    else {
-        xchg <- character(0)
-    }
-    if (isTRUE(TRD == TRUE) == TRUE) {
-        Eout3p <- list()
-        length(Eout3p) <- length(lbs)
-        Einn3p <- list()
-        length(Einn3p) <- length(lbs)
-        TEnt3p <- list()
-        length(TEnt3p) <- length(lbs)
-        for (i in 1:length(tripfl)) {
-            tmpout <- vector()
-            tmpinn <- vector()
-            for (j in 1:length(tripfl[[i]])) {
-                if (isTRUE(tripfl[[i]][j] %in% trou[[i]]) == 
-                  TRUE) 
-                  tmpout[length(tmpout) + 1L] <- tripfl[[i]][j]
-                if (isTRUE(tripfl[[i]][j] %in% trin[[i]]) == 
-                  TRUE) 
-                  tmpinn[length(tmpinn) + 1L] <- tripfl[[i]][j]
-            }
-            rm(j)
-            Eout3p[[i]] <- tmpout
-            Einn3p[[i]] <- tmpinn
-            TEnt3p[[i]] <- c(tmpout, tmpinn)
-        }
-        TEinn <- list()
-        TEout <- list()
-        for (i in 1:length(TEnt3p)) {
-            tmpinn <- vector()
-            tmpout <- vector()
-            for (j in 1:length(TEnt3p[[i]])) {
-                if (isTRUE(length(Eout3p[[i]]) > 0) == TRUE) {
-                  if (isTRUE(!(Einn3p[[i]][j] %in% out[[i]])) == 
-                    TRUE) 
-                    tmpinn <- append(tmpinn, Einn3p[[i]][j])
-                  if (isTRUE(!(Eout3p[[i]][j] %in% inn[[i]])) == 
-                    TRUE) 
-                    tmpout <- append(tmpout, Eout3p[[i]][j])
-                }
-            }
-            rm(j)
-            TEinn[[i]] <- tmpinn
-            TEout[[i]] <- tmpout
-        }
-        rm(i)
-        rm(tmpinn, tmpout)
-        mixe <- list()
-        for (i in seq(lbs)) {
-            mixe[[i]] <- tripfl[[i]][which(!(tripfl[[i]] %in% 
-                c(TEinn[[i]], TEout[[i]])))]
-        }
-        rm(i)
-        Eoutnp <- list()
-        for (i in seq(lbs)) {
-            Eoutnp[[i]] <- unique(c(Eout[[i]], Eout3p[[i]]))
-            Eout[[i]] <- Eoutnp[[i]][which(!(Eoutnp[[i]] %in% 
-                mixe[[i]]))]
-        }
-        rm(i)
-        rm(Eoutnp)
-    }
-    else {
-        mixe <- TEinn <- TEout <- character(0)
-    }
     if (smpl) {
         if (isTRUE(TRD == TRUE) == TRUE) {
             tmp <- list()
@@ -287,17 +88,18 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         ifelse(isTRUE(TRD == TRUE) == TRUE, tt <- dimnames(x)[[3]], 
             NA)
     }
+    bd <- bnd(x, xd, lbs, TRD, r, m, mlt, prsep)
     As <- vector()
-    for (i in 1:length(asym)) {
-        for (j in 1:length(asym[[i]])) {
-            if (isTRUE(length(asym[[i]]) != 0L) == TRUE) {
+    for (i in 1:length(bd$asym)) {
+        for (j in 1:length(bd$asym[[i]])) {
+            if (isTRUE(length(bd$asym[[i]]) != 0L) == TRUE) {
                 if (isTRUE(is.na(dim(x)[3])) == FALSE) {
-                  As <- append(As, paste(lbs[i], asym[[i]][j], 
+                  As <- append(As, paste(lbs[i], bd$asym[[i]][j], 
                     sep = prsep))
                 }
                 else {
-                  ifelse(isTRUE(asym[[i]][j] %in% out[[i]]) == 
-                    TRUE, As <- append(As, paste(lbs[i], asym[[i]][j], 
+                  ifelse(isTRUE(bd$asym[[i]][j] %in% bd$out[[i]]) == 
+                    TRUE, As <- append(As, paste(lbs[i], bd$asym[[i]][j], 
                     sep = prsep)), NA)
                 }
             }
@@ -322,10 +124,10 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
         AS <- as.character(As)
     }
     Rp <- vector()
-    for (i in 1:length(recp)) {
-        for (j in 1:length(recp[[i]])) {
-            if (isTRUE(length(recp[[i]]) != 0L) == TRUE) {
-                Rp <- append(Rp, paste(lbs[i], recp[[i]][j], 
+    for (i in 1:length(bd$recp)) {
+        for (j in 1:length(bd$recp[[i]])) {
+            if (isTRUE(length(bd$recp[[i]]) != 0L) == TRUE) {
+                Rp <- append(Rp, paste(lbs[i], bd$recp[[i]][j], 
                   sep = prsep))
             }
         }
@@ -350,11 +152,11 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     }
     Xc <- vector()
     if (isTRUE(TRD == TRUE) == TRUE) {
-        for (i in 1:length(xchg)) {
-            for (j in 1:length(xchg[[i]])) {
-                if (isTRUE(length(xchg[[i]]) != 0L) == TRUE) {
-                  if (isTRUE(lbs[i] < xchg[[i]][j]) == TRUE) 
-                    Xc <- append(Xc, paste(lbs[i], xchg[[i]][j], 
+        for (i in 1:length(bd$xchg)) {
+            for (j in 1:length(bd$xchg[[i]])) {
+                if (isTRUE(length(bd$xchg[[i]]) != 0L) == TRUE) {
+                  if (isTRUE(lbs[i] < bd$xchg[[i]][j]) == TRUE) 
+                    Xc <- append(Xc, paste(lbs[i], bd$xchg[[i]][j], 
                       sep = prsep))
                 }
             }
@@ -392,10 +194,10 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     }
     Et <- vector()
     if (isTRUE(TRD == TRUE) == TRUE) {
-        for (i in 1:length(Eout)) {
-            for (j in 1:length(Eout[[i]])) {
-                if (isTRUE(length(Eout[[i]]) != 0L) == TRUE) {
-                  Et <- append(Et, paste(lbs[i], Eout[[i]][j], 
+        for (i in 1:length(bd$Eout)) {
+            for (j in 1:length(bd$Eout[[i]])) {
+                if (isTRUE(length(bd$Eout[[i]]) != 0L) == TRUE) {
+                  Et <- append(Et, paste(lbs[i], bd$Eout[[i]][j], 
                     sep = prsep))
                 }
             }
@@ -419,11 +221,11 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     }
     Mx <- vector()
     if (isTRUE(TRD == TRUE) == TRUE) {
-        for (i in 1:length(mixe)) {
-            for (j in 1:length(mixe[[i]])) {
-                if (isTRUE(length(mixe[[i]]) != 0L) == TRUE) {
-                  if (isTRUE(lbs[i] < mixe[[i]][j]) == TRUE) 
-                    Mx <- append(Mx, paste(lbs[i], mixe[[i]][j], 
+        for (i in 1:length(bd$mixe)) {
+            for (j in 1:length(bd$mixe[[i]])) {
+                if (isTRUE(length(bd$mixe[[i]]) != 0L) == TRUE) {
+                  if (isTRUE(lbs[i] < bd$mixe[[i]][j]) == TRUE) 
+                    Mx <- append(Mx, paste(lbs[i], bd$mixe[[i]][j], 
                       sep = prsep))
                 }
             }
@@ -461,11 +263,11 @@ function (x, loops = FALSE, smpl = FALSE, lb2lb = TRUE, collapse = FALSE,
     }
     Fl <- vector()
     if (isTRUE(TRD == TRUE) == TRUE) {
-        for (i in 1:length(full)) {
-            for (j in 1:length(full[[i]])) {
-                if (isTRUE(length(full[[i]]) != 0L) == TRUE) {
-                  if (isTRUE(lbs[i] < full[[i]][j]) == TRUE) 
-                    Fl <- append(Fl, paste(lbs[i], full[[i]][j], 
+        for (i in 1:length(bd$full)) {
+            for (j in 1:length(bd$full[[i]])) {
+                if (isTRUE(length(bd$full[[i]]) != 0L) == TRUE) {
+                  if (isTRUE(lbs[i] < bd$full[[i]][j]) == TRUE) 
+                    Fl <- append(Fl, paste(lbs[i], bd$full[[i]][j], 
                       sep = prsep))
                 }
             }
